pub(crate) struct CommandStorage {
entries: SyncRwLock<FxHashMap<Identifier, NbtCompound>>,
revision: AtomicU64,
saved_revision: AtomicU64,
}Expand description
Vanilla command storage for one Steel domain.
Fields
entries: SyncRwLock<FxHashMap<Identifier, NbtCompound>>revision: AtomicU64saved_revision: AtomicU64Implementations
Sourceimpl CommandStorage
impl CommandStorage
fn from_persistent(persistent: PersistentCommandStorage) -> Result<Self>
Sourcepub(crate) fn get(&self, id: &Identifier) -> NbtCompound
pub(crate) fn get(&self, id: &Identifier) -> NbtCompound
Returns the compound stored at id, or an empty compound when absent.
Sourcepub(crate) fn set(&self, id: Identifier, contents: NbtCompound)
pub(crate) fn set(&self, id: Identifier, contents: NbtCompound)
Stores a compound, removing the key when the compound is empty.
Sourcepub(crate) fn keys(&self) -> Vec<Identifier>
pub(crate) fn keys(&self) -> Vec<Identifier>
Returns stored keys in stable resource-location order.
fn pending_save(&self) -> Option<CommandStorageSaveSnapshot>
fn mark_saved(&self, revision: u64)